'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = codeGenerator;

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function codeGenerator(info) {
  const css = generateCss(info.ast);
  const templateRaw = generateTemplateRaw(css, info.tracks);
  const template = fixLocals(templateRaw, info.tracks);
  return template;
}

function generateCss(ast) {
  let css = '';
  _postcss2.default.stringify(ast, i => {
    css += i;
  });
  return css;
}

function generateTemplateRaw(css, tracks) {
  const tracksLast = tracks.length - 1;
  const defaultsPrettyObj = tracks.reduce((str, track, i) => `${str}\n  ${track.nameJs}: ${track.defaultValue.includes("'") ? JSON.stringify(track.defaultValue) : `'${track.defaultValue}'`}${i === tracksLast ? '' : ','}`, '');
  const defaultsPretty = `{${defaultsPrettyObj ? `${defaultsPrettyObj}\n` : ''}}`;

  const isEmpty = css === '';
  const template = `const defaults = ${defaultsPretty};

const templatize = ${isEmpty ? '()' : 'locals'} => ${isEmpty ? "''" : `\`${css}\``};

module.exports = { defaults, templatize };
`;
  return template;
}

function fixLocals(templateRaw, tracks) {
  let template = templateRaw;
  tracks.forEach(track => {
    const jsVarName = (0, _lodash.camelCase)(track.name);
    template = template.replace(new RegExp(`var\\(${track.name}\\)`, 'g'), `\${locals.${jsVarName} || defaults.${jsVarName}}`);
  });
  return template;
}
//# sourceMappingURL=code-generator.js.map