'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.compile = compile;
exports.compileFile = compileFile;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _util = require('util');

var _util2 = _interopRequireDefault(_util);

var _makeDir = require('make-dir');

var _makeDir2 = _interopRequireDefault(_makeDir);

var _parser = require('./parser');

var _parser2 = _interopRequireDefault(_parser);

var _transformation = require('./transformation');

var _transformation2 = _interopRequireDefault(_transformation);

var _codeGenerator = require('./code-generator');

var _codeGenerator2 = _interopRequireDefault(_codeGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const readFile = _util2.default.promisify(_fs2.default.readFile);
const writeFile = _util2.default.promisify(_fs2.default.writeFile);

function compile(input) {
  const ast = (0, _parser2.default)(input);
  const info = (0, _transformation2.default)(ast);
  const template = (0, _codeGenerator2.default)(info);
  return template;
}

async function compileFile(inputFile, outputFile, { progress = () => {} } = {}) {
  const inputFilePath = _path2.default.resolve(process.cwd(), inputFile);
  const outputFilePath = _path2.default.resolve(process.cwd(), outputFile);
  const inputCode = await readFile(inputFilePath, { encoding: 'utf8' });
  const template = compile(inputCode);
  const outputFilePathDir = _path2.default.dirname(outputFilePath);
  await (0, _makeDir2.default)(outputFilePathDir);
  await writeFile(outputFilePath, template);
  const relativePath = _path2.default.join(process.cwd(), '/');
  progress(`${inputFile.replace(relativePath, '')} -> ${outputFile.replace(relativePath, '')}`);
}
//# sourceMappingURL=index.js.map